import Vuex from 'vuex'
import { mount, createLocalVue } from '@vue/test-utils'
import AutoLogout from '@/components/AutoLogout.vue'
import sinon from 'sinon'
import { Authentication } from '@/store/modules/authentication'
import chai from 'chai'
chai.should()

let localVue = createLocalVue()
localVue.use(Vuex)

describe('Auto Logout Unit Tests', () => {
  let store: any = null
  let consoleTemp = {
    warn: console.warn,
    error: console.error,
  }

  before(function() {
    console.warn = function() {}
    console.error = function() {}
  })

  after(function() {
    console.warn = consoleTemp.warn
    console.error = consoleTemp.error
  })

  beforeEach(() => {
    store = new Vuex.Store({
      state: {}
    })
  })

  afterEach(() => {
    sinon.restore()
  })
  
  it('should be hidden by default', () => {
    let wrapper = mount(AutoLogout, { localVue: localVue, store })
    wrapper.vm.$data.logoutDialog.should.equal(false)
    wrapper.html().should.contain('<div class="v-dialog v-dialog--persistent" style="max-width: 30%; display: none;">')
  })
  it('should be visible when logoutDialog is set to true', () => {
    let store = new Vuex.Store({})
    let wrapper = mount(AutoLogout, { localVue, store })
    wrapper.vm.$data.logoutDialog = true
    wrapper.html().should.contain('<div class="v-dialog v-dialog--active v-dialog--persistent" style="max-width: 30%;">')
  })
  it('should get a refresh token from the server when user clicks button', () => {
    let spy = sinon.spy()
    sinon.replace(Authentication, 'refreshJWT', spy)
    let store = new Vuex.Store({})
    let wrapper = mount(AutoLogout, { localVue, store })
    wrapper.find('#continue-btn').trigger('click')
    spy.called.should.equal(true)
  })
})
